@@ -27,7 +27,7 @@
 #include "icastats.h"
 
 #define CMD_NAME "icastats"
-#define COPYRIGHT "Copyright IBM Corp. 2009-2021"
+#define COPYRIGHT "Copyright IBM Corp. 2009-2023"
 
 void print_version(void)
 {
@@ -302,7 +302,7 @@ int main(int argc, char *argv[])
 				perror("malloc: ");
 				return EXIT_FAILURE;
 			}
-			get_stats_data(entries);
+			get_stats_data(NULL, entries);
 			if (json) {
 				print_stats_json(entries, usr);
 			} else {
@@ -358,7 +358,7 @@ int main(int argc, char *argv[])
 			perror("malloc: ");
 			return EXIT_FAILURE;
 		}
-		get_stats_data(stats);
+		get_stats_data(NULL, stats);
 		if (json) {
 			pswd = getpwuid(user == -1 ? geteuid() : (uid_t)user);
 			if (pswd == NULL) {
